@@ -5,7 +5,7 @@ from inspect import getsourcefile
 from spacy.language import Language
 
 from ..constants import B_DECR, B_INCR
-from ..utils import lexicons
+from ..utils import lexicons, components
 from ..component import Asent
 
 from .emoji import LEXICON as E_LEXICON
@@ -204,3 +204,6 @@ def create_en_sentiment_component(nlp: Language, name: str, force: bool) -> Lang
         lemmatize=False,
         force=force,
     )
+
+
+components.register("asent_en_v1", func=create_en_sentiment_component)
